==> openshift-model-console-6.7.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadListBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsoleCLIDownloadListBuilder extends ConsoleCLIDownloadListFluentImpl<ConsoleCLIDownloadListBuilder> implements VisitableBuilder<ConsoleCLIDownloadList,ConsoleCLIDownloadListBuilder>{
  public ConsoleCLIDownloadListBuilder() {
    this(false);
  }
  public ConsoleCLIDownloadListBuilder(Boolean validationEnabled) {
    this(new ConsoleCLIDownloadList(), validationEnabled);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsoleCLIDownloadList(), validationEnabled);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent,ConsoleCLIDownloadList instance) {
    this(fluent, instance, false);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent,ConsoleCLIDownloadList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadList instance) {
    this(instance,false);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ConsoleCLIDownloadListFluent<?> fluent;
  Boolean validationEnabled;
  public ConsoleCLIDownloadList build() {
    ConsoleCLIDownloadList buildable = new ConsoleCLIDownloadList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-console-6.8.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadListBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsoleCLIDownloadListBuilder extends ConsoleCLIDownloadListFluent<ConsoleCLIDownloadListBuilder> implements VisitableBuilder<ConsoleCLIDownloadList,ConsoleCLIDownloadListBuilder>{
  public ConsoleCLIDownloadListBuilder() {
    this(false);
  }
  public ConsoleCLIDownloadListBuilder(Boolean validationEnabled) {
    this(new ConsoleCLIDownloadList(), validationEnabled);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsoleCLIDownloadList(), validationEnabled);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent,ConsoleCLIDownloadList instance) {
    this(fluent, instance, false);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadListFluent<?> fluent,ConsoleCLIDownloadList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ConsoleCLIDownloadList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadList instance) {
    this(instance,false);
  }
  public ConsoleCLIDownloadListBuilder(ConsoleCLIDownloadList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ConsoleCLIDownloadList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ConsoleCLIDownloadListFluent<?> fluent;
  Boolean validationEnabled;
  public ConsoleCLIDownloadList build() {
    ConsoleCLIDownloadList buildable = new ConsoleCLIDownloadList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
